<?php

/**
 * @file
 * Main administration page for default config.
 */

/**
 * Main administration page callback.
 */
function defaultconfig_admin() {
  $components = defaultconfig_get_components();
  $page = array();
  foreach ($components as $hook => $component) {
    $component['hook'] = $hook;
    $page['tables'][] = array(
      '#title' => $component['label'],
      '#type' => 'item',
      '#markup' => defaultconfig_component_table($component),
    );
  }
  return $page;
}

/**
 * Render a a table with all modules having components of a particular type.
 */
function defaultconfig_component_table($component) {
  $modules = module_implements('defaultconfig_' . $component['hook']);
  if (count($modules)) {
    $data = array();
    // @todo fetch more information about the modules. For now, let's just
    // use the machine name.
    foreach ($modules as $module) {
      $data[] = array($module, l(t('rebuild'),
              'admin/structure/defaultconfig/rebuild/' . $module . '/' . $component['hook']));
    }
    return theme('table', array('header' => array(t('Module'), t('Operations')), 'rows' => $data));
  }
  return t('No modules define default content for %label', array('%label' => $component['label']));
}

/**
 * Rebuild confirmation form.
 */
function defaultconfig_rebuild_form($form, &$form_state, $module, $hook) {
  $components = defaultconfig_get_components();
  if (!module_exists($module) || !isset($components[$hook])) {
    drupal_not_found();
    return '';
  }
  $component = $components[$hook];
  $component['hook'] = $hook;
  $form_state['component'] = $component;
  $form_state['module'] = $module;
  return confirm_form(
    $form,
    t('Are you sure you want to rebuild the defaults in %module for %component?',
      array('%module' => $module, '%component' => $component['label'])),
    'admin/structure/defaultconfig',
    t('Any changes you have made might be undone.')
  );
}

function defaultconfig_rebuild_form_submit($form, &$form_state) {
  $form_state['redirect'] = 'admin/structure/defaultconfig';
  defaultconfig_rebuild($form_state['component'], $form_state['module']);
  drupal_set_message(t('The component %component in %module has been rebuilt.',
    array('%module' => $form_state['module'], '%component' => $form_state['component']['label'])));
}
